======================
threedi-cmd-statistics
======================


Statistics plugin for the 3Di cmd client


* Free software: MIT license
* Documentation: https://threedi-api-stats.readthedocs.io.


Features
--------

* session statistics like counts
* usage overview like total hours calculated
* active customers overview


Installation
------------

This plugin is pip installable. Install alongside with the `threedi-cmd`_ client package ::

    $ pip install threedi-cmd-statistics

The threedi command client will automatically detect the plugin and will add the commands to the
client interface.

.. _threedi-cmd: https://github.com/nens/threedi-cmd

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
